// generated from rosidl_adapter/resource/srv.idl.em
// with input from example_interfaces/srv/AddTwoInts.srv
// generated code does not contain a copyright notice


module example_interfaces {
  module srv {
    struct AddTwoInts_Request {
      int64 a;

      int64 b;
    };
    struct AddTwoInts_Response {
      int64 sum;
    };
  };
};
