// generated from rosidl_adapter/resource/msg.idl.em
// with input from example_interfaces/msg/MultiArrayDimension.msg
// generated code does not contain a copyright notice


module example_interfaces {
  module msg {
    @verbatim (language="comment", text=
      "This is an example of using complex datatypes." "\n"
      "It is not recommended to use directly." "\n"
      "To use a similar datastruct please define a custom message with appropriate semantic meaning.")
    struct MultiArrayDimension {
      @verbatim (language="comment", text=
        "label of given dimension")
      string label;

      @verbatim (language="comment", text=
        "size of given dimension (in type units)")
      uint32 size;

      @verbatim (language="comment", text=
        "stride of given dimension")
      uint32 stride;
    };
  };
};
